import{u as S,V as c,a as i,m as A,b as R}from"./VInput-B3Z2GK8Z.js";import{x as _,y as D,a0 as U,i as q,c2 as z,C as E,c3 as M,b as m,aA as p,aI as $,S as j,d as G,c as n,o as r,F as H,q as b,D as f,a as l}from"./index-LFx1jIjH.js";const J=D({...A(),...j(R(),["inline"])},"VCheckbox"),O=_()({name:"VCheckbox",inheritAttrs:!1,props:J(),emits:{"update:modelValue":e=>!0,"update:focused":e=>!0},setup(e,a){let{attrs:s,slots:u}=a;const o=U(e,"modelValue"),{isFocused:y,focus:V,blur:v}=S(e),d=q(),k=z();return E(()=>{const[g,h]=M(s),B=c.filterProps(e),w=i.filterProps(e);return m(c,p({ref:d,class:["v-checkbox",e.class]},g,B,{modelValue:o.value,"onUpdate:modelValue":t=>o.value=t,id:e.id||`checkbox-${k}`,focused:y.value,style:e.style}),{...u,default:t=>{let{id:C,messagesId:P,isDisabled:x,isReadonly:I,isValid:F}=t;return m(i,p(w,{id:C.value,"aria-describedby":P.value,disabled:x.value,readonly:I.value},h,{error:F.value===!1,modelValue:o.value,"onUpdate:modelValue":N=>o.value=N,onFocus:V,onBlur:v}),u)}})}),$({},d)}}),Q=G({__name:"NowPlayingBadge",props:{showBadge:{type:Boolean,default:!0},showIcon:{type:Boolean,default:!0},badgeStyle:{default:""},iconStyle:{default:""}},setup(e){return(a,s)=>(r(),n(H,null,[a.showBadge?(r(),n("span",{key:0,style:f(a.badgeStyle),class:"now-playing-badge","aria-label":"Now playing"}," Now playing ",4)):b("",!0),a.showIcon?(r(),n("div",{key:1,style:f(a.iconStyle),class:"now-playing-icon"},[...s[0]||(s[0]=[l("div",{class:"bar"},null,-1),l("div",{class:"bar"},null,-1),l("div",{class:"bar"},null,-1),l("div",{class:"bar"},null,-1)])],4)):b("",!0)],64))}});export{O as V,Q as _};
