/* empty css              */import{x as t,y as l,Q as r,z as i,C as m,G as c,H as u,I as C,b as d,D as p,E as y}from"./index-LFx1jIjH.js";const f=l({fluid:{type:Boolean,default:!1},...C(),...u(),...c()},"VContainer"),v=t()({name:"VContainer",props:f(),setup(e,s){let{slots:a}=s;const{rtlClasses:n}=r(),{dimensionStyles:o}=i(e);return m(()=>d(e.tag,{class:y(["v-container",{"v-container--fluid":e.fluid},n.value,e.class]),style:p([o.value,e.style])},a)),{}}});export{v as V};
