import{d as v,j as y,e as i,o as t,L as b,u as n,bu as k,w as a,aR as C,c as p,E as V,b as l,a as g,q as w,v as _,t as c,J as h,bs as $,F as B,r as M,bv as A,M as m,b4 as I}from"./index-LFx1jIjH.js";import{P as T}from"./PanelviewItemCompact-Bf82DAtE.js";import{V as E}from"./VToolbar-Dc2WDt1C.js";import{a as u}from"./VBtn-BYKkZzw0.js";import{V as N}from"./VAlert-Cyb25ra3.js";import{_ as z}from"./_plugin-vue_export-helper-DlAUqK2U.js";const L=v({__name:"Carousel",setup(R){return y(()=>{document.documentElement.style.setProperty("--swiper-navigation-color","primary")}),(d,r)=>{const e=b("swiper");return t(),i(e,{"slides-per-view":n(k)(d.$vuetify.display.width)+.5,"free-mode":!0,navigation:!1,mousewheel:{forceToAxis:!0,releaseOnEdges:!0}},{default:a(()=>[C(d.$slots,"default")]),_:3},8,["slides-per-view"])}}}),P={class:"mr-3"},W={key:0},D={class:"carousel-wrapper"},F=v({__name:"WidgetRow",props:{widgetRow:{},editMode:{type:Boolean}},emits:["update:settings"],setup(R,{emit:d}){const r=d;return(e,o)=>{const f=b("swiper-slide");return t(),p("div",{class:V(`widget-row ${e.widgetRow.settings&&!e.widgetRow.settings.enabled?"disabled":""}`)},[l(E,{class:"header",color:"transparent"},{title:a(()=>[g("span",P,c(e.widgetRow.title),1),e.widgetRow.subtitle&&n(h)("bp6")?(t(),i($,{key:0,inline:"",outlined:"",text:e.widgetRow.subtitle,density:"compact",size:"small"},null,8,["text"])):w("",!0)]),append:a(()=>[e.editMode&&e.widgetRow.settings?(t(),p("div",W,[e.widgetRow.settings.position!==0?(t(),i(u,{key:0,icon:"mdi-chevron-up",class:"enabled",onClick:o[0]||(o[0]=s=>r("update:settings",{...e.widgetRow.settings,position:e.widgetRow.settings.position-1}))})):w("",!0),l(u,{icon:"mdi-chevron-down",onClick:o[1]||(o[1]=s=>r("update:settings",{...e.widgetRow.settings,position:e.widgetRow.settings.position+1}))}),l(u,{icon:e.widgetRow.settings.enabled?"mdi-checkbox-marked":"mdi-checkbox-blank-outline",onClick:o[2]||(o[2]=s=>r("update:settings",{...e.widgetRow.settings,enabled:!e.widgetRow.settings.enabled}))},null,8,["icon"])])):e.widgetRow.provider?(t(),i(_,{key:1,domain:e.widgetRow.provider,size:24},null,8,["domain"])):w("",!0)]),_:1}),g("div",D,[e.widgetRow.items.length>0?(t(),i(L,{key:0},{default:a(()=>[(t(!0),p(B,null,M(e.widgetRow.items,s=>(t(),i(f,{key:s.uri},{default:a(()=>[l(T,{item:s,"permanent-overlay":![n(m).ALBUM,n(m).TRACK,n(m).RADIO].includes(s.media_type),"is-available":n(A)(s),disabled:e.editMode},null,8,["item","permanent-overlay","is-available","disabled"])]),_:2},1024))),128))]),_:1})):(t(),i(N,{key:1},{default:a(()=>[I(c(e.$t("no_content")),1)]),_:1}))])],2)}}}),U=z(F,[["__scopeId","data-v-b4fbe42a"]]);export{U as W};
