import{d as u,N as l,bJ as c,c as p,o as i,b as r,a as m,p as d,w as v,L as g,e as f,K as b}from"./index-LFx1jIjH.js";import{T as h}from"./Toolbar-iQxHKI_C.js";import"./VToolbar-Dc2WDt1C.js";import"./VBtn-BYKkZzw0.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";const C=u({__name:"Settings",setup(y){const n=c(),t=l(()=>n.currentRoute.value.name?.toString().includes("player")?"players":n.currentRoute.value.name?.toString().includes("core")?"core":n.currentRoute.value.name?.toString().includes("frontend")?"frontend":"providers");return(e,o)=>{const a=g("router-view");return i(),p("div",null,[r(h,{icon:"mdi-cog-outline",title:e.$t("settings.settings"),"show-loading":!0,"menu-items":[{label:"settings.providers",icon:"mdi-apps",action:()=>{e.$router.push({name:"providersettings"})},active:t.value=="providers"},{label:"settings.players",icon:"mdi-speaker-multiple",action:()=>{e.$router.push({name:"playersettings"})},active:t.value=="players"},{label:"settings.core",icon:"mdi-engine",action:()=>{e.$router.push({name:"coresettings"})},active:t.value=="core"},{label:"settings.frontend",icon:"mdi-palette-advanced",action:()=>{e.$router.push({name:"frontendsettings"})},active:t.value=="frontend"}]},null,8,["title","menu-items"]),r(d),o[0]||(o[0]=m("div",{style:{height:"15px"}},null,-1)),r(a,{app:""},{default:v(({Component:s})=>[(i(),f(b(s)))]),_:1})])}}});export{C as default};
