import{I as f,_ as v}from"./ProviderDetails.vue_vue_type_script_setup_true_lang-bItMFJVo.js";import{I as _}from"./ItemsListing-BHlkb6-j.js";import{d as I,i as m,ad as h,j as b,m as a,a_ as y,l as k,c as w,o as i,b as E,e as p,q as n,F as D}from"./index-LFx1jIjH.js";import"./MediaItemThumb-cYqdWFcl.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./Toolbar-iQxHKI_C.js";import"./VToolbar-Dc2WDt1C.js";import"./VBtn-BYKkZzw0.js";import"./marquee_text_sync-AxiznPti.js";import"./VDialog-zNF2U_x9.js";import"./layout-C6GuZOkj.js";import"./Container-CuH2YNr5.js";import"./Button-SUce42c3.js";import"./VContainer-or1Uze2V.js";/* empty css              */import"./ListItem-DhvO1M3C.js";import"./NowPlayingBadge.vue_vue_type_style_index_0_lang-B4veTxLS.js";import"./VInput-B3Z2GK8Z.js";import"./PanelviewItemCompact-Bf82DAtE.js";import"./VSpacer-Cg-cZSyv.js";import"./VTextField-DyzwZgKh.js";import"./VInfiniteScroll-DH2IK80_.js";import"./VRow-cyJLSUM5.js";import"./VVirtualScroll-DYZmdOFl.js";import"./VAlert-Cyb25ra3.js";const W=I({__name:"PodcastDetails",props:{itemId:{},provider:{}},setup(l){const t=l,r=m(!1),e=m(),d=async function(){e.value=await a.getPodcast(t.itemId,t.provider)};h(()=>t.itemId,o=>{o&&d()},{immediate:!0}),b(()=>{const o=a.subscribe(y.MEDIA_ITEM_UPDATED,s=>{const c=s.data;e.value?.uri==c.uri&&(r.value=!0)});k(o)});const u=async function(o){return await a.getPodcastEpisodes(t.itemId,t.provider)};return(o,s)=>(i(),w(D,null,[E(f,{item:e.value},null,8,["item"]),e.value?(i(),p(_,{key:0,itemtype:"podcastepisodes","parent-item":e.value,"show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!0,"show-refresh-button":!0,"load-items":u,"sort-keys":["position","position_desc","name","duration","duration_desc"],"update-available":r.value,title:o.$t("podcast_episodes"),"allow-key-hooks":!0,path:`podcast.${t.itemId}.${t.provider}`,"restore-state":!0,"no-server-side-sorting":!0},null,8,["parent-item","update-available","title","path"])):n("",!0),e.value?(i(),p(v,{key:1,"item-details":e.value},null,8,["item-details"])):n("",!0)],64))}});export{W as default};
