import{x as P,y as I,a0 as M,aB as D,aE as S,d as A,e as i,o as s,w as t,ae as X,n as Y,aA as H,b0 as V,q as n,a as g,b as r,bl as N,c,u as f,s as T,V as z,f as E,M as L,t as l,bQ as O,E as w,by as m,b4 as u,bd as $,bS as F,bz as R,bR as j,bK as q}from"./index-LFx1jIjH.js";import{V as K,_ as Q}from"./NowPlayingBadge.vue_vue_type_style_index_0_lang-B4veTxLS.js";import{M as G}from"./MediaItemThumb-cYqdWFcl.js";import{a as J}from"./VBtn-BYKkZzw0.js";import{_ as U}from"./_plugin-vue_export-helper-DlAUqK2U.js";const W=I({disabled:Boolean,modelValue:{type:Boolean,default:null},...S()},"VHover"),Z=P()({name:"VHover",props:W(),emits:{"update:modelValue":o=>!0},setup(o,y){let{slots:a}=y;const d=M(o,"modelValue"),{runOpenDelay:p,runCloseDelay:b}=D(o,h=>!o.disabled&&(d.value=h));return()=>a.default?.({isHovering:d.value,props:{onMouseenter:p,onMouseleave:b}})}}),_={class:"thumb-container"},x={key:1,class:"play-button-overlay"},ee={key:0},ae=A({__name:"PanelviewItemCompact",props:{item:{},size:{default:200},isSelected:{type:Boolean,default:!1},showCheckboxes:{type:Boolean,default:!1},permanentOverlay:{type:Boolean,default:!1},isAvailable:{type:Boolean,default:!0},isPlaying:{type:Boolean},parentItem:{default:void 0},disabled:{type:Boolean}},emits:["select"],setup(o,{emit:y}){const a=o,d=y,p=function(e){if(a.showCheckboxes)return;const k="clientX"in e?e.clientX:e.touches[0].clientX,v="clientY"in e?e.clientY:e.touches[0].clientY;j(a.item,k,v,a.parentItem)},b=function(e){if(a.showCheckboxes){d("select",a.item,!a.isSelected);return}F(a.item,e.clientX,e.clientY,a.parentItem)},h=function(e){a.showCheckboxes||q(a.item,e.clientX,e.clientY,a.parentItem)};return(e,k)=>{const v=R("hold");return s(),i(Z,null,{default:t(({isHovering:C,props:B})=>[X((s(),i(Y,H(B,{class:{"on-hover":C,unavailable:!e.isAvailable},elevation:"0",disabled:e.disabled,onClick:b,onContextmenu:V(p,["right","prevent"])}),{default:t(()=>[e.showCheckboxes?(s(),i(N,{key:0,"model-value":e.showCheckboxes,contained:"",scrim:e.isSelected?e.$vuetify.theme.current.dark?"rgba(0,0,0,.75)":"rgba(255,255,255,.75)":"#ffffff00"},{default:t(()=>[r(K,{class:"panel-item-checkbox",ripple:!1,"model-value":e.isSelected},null,8,["model-value"])]),_:1},8,["model-value","scrim"])):n("",!0),g("div",_,[r(G,{item:e.isAvailable?e.item:void 0},null,8,["item"]),e.isPlaying?(s(),i(Q,{key:0,"icon-style":"position: absolute; right: 5px; bottom: 5px","show-badge":!1})):n("",!0),(C||f(T).isTouchscreen)&&e.isAvailable&&e.item.is_playable?(s(),c("div",x,[r(J,{icon:"mdi-play",color:"white",fab:"",style:{opacity:"0.6","font-size":"20px"},onClick:V(h,["stop"])})])):n("",!0)]),r(z,{variant:"text",slim:"",tile:"",density:"compact",class:"panel-item-details"},{default:t(()=>[r(E,null,{default:t(()=>[e.item.media_type==f(L).FOLDER?(s(),c("span",ee,[g("span",null,l(f(O)(e.item,e.$t)),1)])):(s(),c("span",{key:1,class:w({"is-playing":e.isPlaying})},l(e.item.name),3)),"version"in e.item&&e.item.version?(s(),c("span",{key:2,class:w({"is-playing":e.isPlaying})}," - "+l(e.item.version),3)):n("",!0)]),_:1}),"artists"in e.item&&e.item.artists?(s(),i(m,{key:0,class:"line-clamp-1"},{default:t(()=>[u(l(f($)(e.item.artists,1)),1)]),_:1})):n("",!0),"authors"in e.item&&e.item.authors?(s(),i(m,{key:1,class:"line-clamp-1"},{default:t(()=>[u(l(e.item.authors.join(" / ")),1)]),_:1})):"publisher"in e.item&&e.item.publisher?(s(),i(m,{key:2,class:"line-clamp-1"},{default:t(()=>[u(l(e.item.publisher),1)]),_:1})):"owner"in e.item&&e.item.owner?(s(),i(m,{key:3,class:"line-clamp-1"},{default:t(()=>[u(l(e.item.owner),1)]),_:1})):"provider_mappings"in e.item?n("",!0):(s(),i(m,{key:4,class:"line-clamp-1"},{default:t(()=>[u(l(e.$t(e.item.media_type)),1)]),_:1}))]),_:1})]),_:2},1040,["class","disabled"])),[[v,p]])]),_:1})}}}),ne=U(ae,[["__scopeId","data-v-4a833c3f"]]);export{ne as P,Z as V};
